
import os
import sys

HOME   = os.path.basename(sys.argv[0])
PUBLIC = HOME + '/public

PATH_ACTION = os.path.basepath(__file__)

print 'HOME', HOME
print 'PUBL', PUBLIC
print 'ACTN', PATH_ACTION

import compact
import template
import database
import http






from distutils.core import setup

setup(
    name='ActionServer',
    author='Josueh Machado',
    author_email='josueh.cg@gmail.com',
    description=('Framework Web (Tornado + Django)'),
    version='0.2dev',
    packages=['action',],
    license='CC by Josueh',
)

''' INSTRUCTION FOR UPDATE PACKAGE:
    $ python setup.py sdist
    $ python setup.py register
    $ python setup.py sdist upload
'''
